#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var commander = require("commander");
var diff_1 = require("./cli/commands/diff");
var validate_1 = require("./cli/commands/validate");
var similar_1 = require("./cli/commands/similar");
var serve_1 = require("./cli/commands/serve");
var coverage_1 = require("./cli/commands/coverage");
var options_1 = require("./cli/utils/options");
commander.option('-r, --require <s...>', 'Require modules');
commander
    .command('diff <old> <new>')
    .description('Diff two schemas')
    .action(function (oldSchema, newSchema, cmd) {
    return diff_1.diff(oldSchema, newSchema, options_1.normalizeOptions(cmd));
});
commander
    .command('validate <documents> <schema>')
    .description('Validate documents against a schema')
    .action(function (documents, schema, cmd) {
    return validate_1.validate(documents, schema, options_1.normalizeOptions(cmd));
});
commander
    .command('similar <schema>')
    .option('-n, --type <s>', 'Name of a type')
    .option('-t, --threshold <n>', 'Threshold of similarity ratio', parseFloat)
    .description('Find similar types in a schema')
    .action(function (schema, cmd) {
    similar_1.similar(schema, cmd.type, cmd.threshold, options_1.normalizeOptions(cmd));
});
commander
    .command('serve <schema>')
    .description('Serves a GraphQL API with Playground')
    .action(function (schema, cmd) {
    return serve_1.serve(schema, options_1.normalizeOptions(cmd));
});
commander
    .command('coverage <documents> <schema>')
    .option('-s, --silent', 'Do not render any stats in the terminal')
    .option('-w, --write <s>', 'Write a file with coverage stats')
    .description('Schema coverage based on documents')
    .action(function (documents, schema, cmd) {
    return coverage_1.coverage(documents, schema, options_1.normalizeOptions(cmd));
});
commander.parse(process.argv);
//# sourceMappingURL=cli.js.map